use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/XML/CompareML.pm',
    'lib/XML/CompareML/Base.pm',
    'lib/XML/CompareML/DTD/Generate.pm',
    'lib/XML/CompareML/DocBook.pm',
    'lib/XML/CompareML/HTML.pm',
    't/00-compile.t',
    't/00-load.t',
    't/01generate.t',
    't/02sys-list.t',
    't/files/scm-comparison.xml',
    't/files/scm-sys-list-1.xml'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
