use Test::More tests => 4;

BEGIN
{
    # TEST
    use_ok('XML::CompareML::Base');

    # TEST
    use_ok('XML::CompareML::DocBook');

    # TEST
    use_ok('XML::CompareML::HTML');

    # TEST
    use_ok('XML::CompareML');
}
